# Code of conduct

(``pdbp`` uses a modified version of [Flutter's Code of conduct](https://github.com/flutter/flutter/blob/master/CODE_OF_CONDUCT.md))

The ``pdbp`` project expects contributors to act professionally and respectfully. ``pdbp`` contributors are expected to maintain the safety and dignity of social environments (such as GitHub and Gitter).

Specifically:

* Respect people, their identities, their culture, and their work.
* Be kind. Be courteous. Be welcoming.
* Listen. Consider and acknowledge people's points before responding.

Should you experience anything that makes you feel unwelcome in our community, please [contact us](https://gitter.im/seleniumbase/SeleniumBase).

The ``pdbp`` project will not tolerate harassment in our community, even outside of our public communication channels.

## Questions

It's always OK to ask questions. ``pdbp`` is a big project, and we don't expect everyone to know everything about everything.

!["I try not to make fun of people for admitting they don't know things, because for each thing 'everyone knows' by the time they're adults, every day there are, on average, 10,000 people in the US hearing about it for the first time. If I make fun of people, I train them not to tell me when they have those moments. And I miss out on the fun." "Diet coke and mentos thing? What's that?" "Oh, man! We're going to the grocery store." "Why?" "You're one of today's lucky 10,000."](https://imgs.xkcd.com/comics/ten_thousand.png)

Source: _[xkcd, May 2012](https://xkcd.com/1053/)_
